==> ncar_0.4.3.tar.gz: ncar/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{ncar}}
\section{Changes in version 0.4.3 (2021-06-11)}{
  \itemize{
    \item{Handles NA better with less error in the plot.}
  }
}
\section{Changes in version 0.4.2 (2018-09-27)}{
  \itemize{
    \item{Some sentences are revised.}
  }
}
\section{Changes in version 0.4.1 (2018-07-20)}{
  \itemize{
    \item{Argument \code{key} replaced \code{key} in \code{rtfNCA} and \code{pdfNCA} function.}
  }
}
\section{Changes in version 0.4.0 (2018-06-20)}{
  \itemize{
    \item{Deprecated option in \code{Sys.timezone()}. is removed.}
  }
}
\section{Changes in version 0.3.9 (2018-05-10)}{
  \itemize{
    \item{Calling twice for terminal slope is corrected.}
  }
}
\section{Changes in version 0.3.8 (2018-04-10)}{
  \itemize{
    \item{Errata in manual corrected.}
  }
}
\section{Changes in version 0.3.7 (2017-08-16)}{
  \itemize{
    \item{\pkg{ncar} to be compatible with NonCompart_0.3.3.}
  }
}
\section{Changes in version 0.3.6 (2017-07-18)}{
  \itemize{
    \item{\pkg{ncar} A bug in C0 calcuation of IV bolus case was fixed.}
  }
}
\section{Changes in version 0.3.5 (2017-07-10)}{
  \itemize{
    \item{\pkg{ncar} depends on \pkg{NonCompart}}
  }
}
\section{Changes in version 0.3.4 (2017-03-12)}{
  \itemize{
    \item{\pkg{ncar} does not sort subject ID any more.}
  }
}
\section{Changes in version 0.3.3 (2017-03-12)}{
  \itemize{
    \item{Various report functions like pdfNCA, rtfNCA, and txtNCA are added.}
    \item{IndiNCA and NCA are deprecated.}
  }
}

==> ncar_0.4.4.tar.gz: ncar/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{ncar}}
\section{Changes in version 0.4.4 (2021-07-09)}{
  \itemize{
    \item{\code{mayExcludeLast} option added to pdfNCA, rtfNCA, txtNCA. This option works with NonCompart 0.4.9 or later.}
  }
}
\section{Changes in version 0.4.3 (2021-06-11)}{
  \itemize{
    \item{Handles NA better with less error in the plot.}
  }
}
\section{Changes in version 0.4.2 (2018-09-27)}{
  \itemize{
    \item{Some sentences are revised.}
  }
}
\section{Changes in version 0.4.1 (2018-07-20)}{
  \itemize{
    \item{Argument \code{key} replaced \code{key} in \code{rtfNCA} and \code{pdfNCA} function.}
  }
}
\section{Changes in version 0.4.0 (2018-06-20)}{
  \itemize{
    \item{Deprecated option in \code{Sys.timezone()}. is removed.}
  }
}
\section{Changes in version 0.3.9 (2018-05-10)}{
  \itemize{
    \item{Calling twice for terminal slope is corrected.}
  }
}
\section{Changes in version 0.3.8 (2018-04-10)}{
  \itemize{
    \item{Errata in manual corrected.}
  }
}
\section{Changes in version 0.3.7 (2017-08-16)}{
  \itemize{
    \item{\pkg{ncar} to be compatible with NonCompart_0.3.3.}
  }
}
\section{Changes in version 0.3.6 (2017-07-18)}{
  \itemize{
    \item{\pkg{ncar} A bug in C0 calcuation of IV bolus case was fixed.}
  }
}
\section{Changes in version 0.3.5 (2017-07-10)}{
  \itemize{
    \item{\pkg{ncar} depends on \pkg{NonCompart}}
  }
}
\section{Changes in version 0.3.4 (2017-03-12)}{
  \itemize{
    \item{\pkg{ncar} does not sort subject ID any more.}
  }
}
\section{Changes in version 0.3.3 (2017-03-12)}{
  \itemize{
    \item{Various report functions like pdfNCA, rtfNCA, and txtNCA are added.}
    \item{IndiNCA and NCA are deprecated.}
  }
}
